********************************************************************************
******** Get information from the different modules ********
********************************************************************************

clear all
set more off
cap log close




* 1) Household roster: data set hh1a

use "C:\Data\LiK2013\hh1a.dta", clear

* age
rename h103a age

* ethnicity
rename h105 ethnicity

keep hhid pid age ethnicity
save "C:\Replication\roster.dta", replace





* 2) Education: data set id2a

* Individuals are requested to fill in the education module only if they have not already done so in previous years or if there were changes in the 
* educational status since the last wave. We therefore need to rely on information on education from previous years as well. 


*** start with the 2013 wave
use "C:\Data\LiK2013\id2a.dta", clear

* education
* we rely on highest educational degree obtained - we will calculate the years of schooling from this variable
tab i211, m
* there are no people with a doctorate degree
rename i211 education
keep hhid pid education
drop if education == .
rename hhid hhid13
rename pid pid13
sort hhid13 pid13
save "C:\Replication\edu13.dta", replace



*** 2012 wave 
use "C:\Data\LiK2012\id2.dta", clear
tab i207, m
* there are only 3 people in total with doctorate degree 
* we add doctorate degree to the university category
rename i207 education
replace education = 7 if education == 8
keep hhid pid education 
rename hhid hhid12
rename pid pid12
sort hhid12 pid12
save "C:\Replication\edu12.dta", replace



*** We now combine the information from 2012 and 2013 
// Since hhid and pid are not identical across years, we first need to produce a file which defines how to merge information on the same individuals across the years. 
// This information is contained in the cc_ind data set.

use "C:\Data\LIK2013\cc_ind.dta", clear
* there are some observations in this dataset that were neither part of the 2012 nor of the 2013 sample (they participated only in 2011 and/or 2010)
drop if hhid12 == . & pid12 == . & pid13 == .			// 476 observations deleted

* assign the household ID for 2012; this is the same as 2013 if not a new household was formed; in the latter cases, hhid12 is already filled
replace hhid12 = hhid13 if hh_new == 0 & ind_new == 0

* there are two households with ID 2122 (in 2012); one of them has the exact same composition in 2012; the other must have had a different HHID but we do not know which one it is
* I drop the second household: 4 household members aged 23, 58, 28, 1
drop if hhid13 == 2801 & hhid12 == 2122

duplicates list hhid13 pid13 if pid13 != .
* there are 13 pairs of duplicates in hhid13 pid13
* these are pretty obvious mistakes which can be easily detected by looking at these observations; I correct them by hand
replace pid13 = 4 if hhid13 == 3084 & hhid12 == .
replace pid13 = 4 if hhid13 == 3094 & hhid12 == 3094 & pid12 == 4
replace pid13 = 6 if hhid13 == 3294 & hhid12 == 3294 & pid12 == 6
replace pid13 = 7 if hhid13 == 3431 & hhid12 == 3431 & pid12 == 7 
replace pid13 = 5 if hhid13 == 6015 & hhid12 == 6015 & pid12 == 5
replace pid13 = 6 if hhid13 == 6061 & hhid12 == 6061 & pid12 == 6
replace pid13 = 5 if hhid13 == 6131 & hhid12 == 6131 & pid12 == 5
replace pid13 = 3 if hhid13 == 6391 & hhid12 == 6391 & pid12 == 3
replace pid13 = 7 if hhid13 == 6405 & hhid12 == 6405 & pid12 == 7
replace pid13 = 4 if hhid13 == 6449 & hhid12 == 6449 & pid12 == 4
replace pid13 = 3 if hhid13 == 8065 & hhid12 == 8065 & pid12 == 3
replace pid13 = 2 if hhid13 == 8102 & hhid12 == 8102 & pid12 == 2
replace pid13 = 7 if hhid13 == 21142 & hhid12 == 21142 & pid12 == 7

duplicates list hhid12 pid12 if pid12 != .
* there are 2 pairs of duplicates in hhid12 pid12
* they are also easy to correct because these people left their own hosuehold and are now in a new household
drop if hhid12 == 3121 & pid12 == 6 & hhid13 == 3121
drop if hhid12 == 3121 & pid12 == 7 & hhid13 == 3121

keep hhid12 pid12 hhid13 pid13
sort hhid12 pid12
save "C:\Replication\cc_ind13.dta", replace




*** we now put these datasets together
use "C:\Replication\cc_ind13.dta", clear
drop if hhid12 == . | pid12 == .
merge 1:1 hhid12 pid12 using "C:\Replication\edu12.dta"
// 7,308 are merged
keep if _m == 3
drop _m
gen year = 2012
save "C:\Replication\education12.dta", replace


use "C:\Replication\cc_ind13.dta", clear
sort hhid13 pid13
drop if pid13 == .
merge 1:1 hhid13 pid13 using "C:\Replication\edu13.dta"
// 1,032 are merged
keep if _m == 3
drop _m
gen year = 2013
save "C:\Replication\education13.dta", replace


append using "C:\Replication\education12.dta"
sort hhid13 pid13 
* there are still people with pid13 == . 
drop if pid13 == .
// 227 dropped


* and there are people who filled in the education questions in 2012 AND 2013 - People whose educational background changed were supposed to report their 
* education in 2013; we use the most recent information as such were the instructions
duplicates list hhid13 pid13
// 370 duplicates: provided education information in both years 
* we need to identify these duplicates
by hhid13 pid13: gen count = _N
drop if count == 2 & year == 2012
// 370 dropped
drop count
rename hhid13 hhid 
rename pid13 pid
drop year
save "C:\Replication\education.dta", replace



**** we have information on education from 7,743 individuals  
**** we check whether education is known for every individual who participated in the 2013 LIK 
**** we do so by merging the computed education file with the first module of the individual questionnaire of the 2013 LIK
sort hhid pid
merge 1:1 hhid pid using "C:\Data\LiK2013\id1.dta"
// 7,249 merged
// 494 _m=1: only information about education, no information from this 2013 module; these people were interviewed in 2012 but were not part in 2013
// 403 _m=2: for these people, I have information from the 2013 module but no education information; these people are either new to the survey or 
// did not respond to education questions in 2012
// If the latter, we should be able to retract educational attainment for them from earlier surveys; hence, merge education information from 2011 
keep hhid12 pid12 hhid pid education _merge
keep if _m == 2
drop _m
drop education
save "C:\Replication\education_help.dta", replace


* get information on education from 2011
*** prepare 2012
use "C:\Data\LIK2012\cc_ind.dta", clear
drop if pid12 == .							// 399 observations were part of the 2011 sample but are no longer part of the 2012 sample
* in addition, there are 27 cases that were listed to have moved or died but have pid != . (except for 1 case, all in Jalalabad; seems to be a matter of poor interviewers)
* we checked the id1 module; they are not part of the sample 
drop if i_attr == 1							// 27 observations are deleted
keep hhid12 pid12 hhid11 pid11
save "C:\Replication\cc_ind12.dta", replace
sort hhid12 pid12
merge 1:1 hhid12 pid12 using "C:\Replication\cc_ind13.dta"
drop _m
* drop observations that didn't exist in 2011
drop if hhid11 == . | pid11 == . | pid11 == 0
count if hhid13 != . & pid13 != .					// 11,273 observations observed between 2011 and 2013
save "C:\Replication\merge11_13.dta", replace


use "C:\Replication\merge11_13.dta", clear
// this dataset identifies individuals over time
* one duplicate
drop if hhid11 == 6066 & pid11 == 3 & hhid13 == .
rename hhid11 hhid
rename pid11 pid
sort hhid pid 
merge 1:1 hhid pid using "C:\Data\LIK2011\id2.dta"
keep if _m == 3
drop _m
rename hhid hhid11
rename pid pid11
keep hhid11 pid11 hhid13 pid13 i207
rename i207 education
drop if hhid13 == . | pid13 == .
// 6,620 observations
rename hhid13 hhid
rename pid13 pid
sort hhid pid
save "C:\Replication\edu11.dta", replace


// we only want to obtain education information for those who do not yet have information on education (maximum: 403 observations)
use "C:\Replication\education_help.dta", clear
merge 1:1 hhid pid using "C:\Replication\edu11.dta"
// for 119, I get the information from 2011
keep if _m == 3
keep hhid12 pid12 hhid pid education

append using "C:\Replication\education.dta"
sort hhid pid 
duplicates list hhid pid 
// no duplicates
save "C:\education.dta", replace




* 3) personality: data set id2c

* Again, information on personality was only asked if respondents were not interviewed in 2012. Otherwise, information needs to be retrieved from 2012.


*** 2013 wave

use "C:\Data\LiK2013\id2c.dta", clear

* personality items
tab i244_1, m
tab i244_2, m
tab i244_3, m
tab i244_4, m
tab i244_5, m
tab i244_6, m
tab i244_7, m
tab i244_8, m
tab i244_9, m
tab i244_10, m
tab i244_11, m
tab i244_12, m
tab i244_13, m
tab i244_14, m
tab i244_15, m
tab i244_16, m
tab i244_17, m
tab i244_18, m
tab i244_19, m
tab i244_20, m
tab i244_21, m
// for those who filled this in, there are no missing values

* rename from i244 to pers
forvalues i = 1(1)21 {
	rename i244_`i' pers`i' 	
	}

rename hhid hhid13
rename pid pid13	
save "C:\Replication\personality13.dta", replace



*** 2012 wave
use "C:\Data\LiK2012\id2.dta", clear

* keep only personality 
keep hhid pid i225_*

tab i225_01, m
tab i225_02, m
tab i225_03, m
tab i225_04, m
tab i225_05, m
tab i225_06, m
tab i225_07, m
tab i225_08, m
tab i225_09, m
tab i225_10, m
tab i225_11, m
tab i225_12, m
tab i225_13, m
tab i225_14, m
tab i225_15, m
tab i225_16, m
tab i225_17, m
tab i225_18, m
tab i225_19, m
tab i225_20, m
tab i225_21, m
// 26 missing values in all of these questions, which means that 26 individuals did not respond to this question
* only in the first question, these 26 people have answer = 9
replace i225_01 = . if i225_01 == 9
* we drop these 26 observations because we cannot compute personality traits
drop if i225_01 == .


* rename the variable in the same way as in 2013
forvalues i = 1(1)9 {
	rename i225_0`i' pers`i' 	
	}

forvalues i = 10(1)21 {
	rename i225_`i' pers`i' 	
	}

rename hhid hhid12
rename pid pid12	
save "C:\Replication\personality12.dta", replace



*** combine these data sets 
use "C:\Replication\cc_ind13.dta", clear
drop if hhid12 == . | pid12 == .
merge 1:1 hhid12 pid12 using "C:\Replication\personality12.dta"
// 7,284 are merged
keep if _m == 3
drop _m
gen year = 2012
save "C:\Replication\personality12.dta", replace


use "C:\Replication\cc_ind13.dta", clear
sort hhid13 pid13
drop if pid13 == .
merge 1:1 hhid13 pid13 using "C:\Replication\personality13.dta"

// 868 are merged
keep if _m == 3
drop _m
gen year = 2013
save "C:\Replication\personality13.dta", replace


append using "C:\Replication\personality12.dta"
sort hhid13 pid13 
* there are still people with pid13 == . 
drop if pid13 == .
// 223 dropped

* and there are people who filled in the personality questions in 2012 AND 2013 - for those who were 
* interviewed in both years, we will use information from 2012 as such were the instructions (they should not have answered the question again in 2013)
duplicates list hhid13 pid13
// 41 duplicates: provided personality information in both years 
* we need to identify these duplicates
by hhid13 pid13: gen count = _N
drop if count == 2 & year == 2013
// 41 dropped
drop count
rename hhid13 hhid 
rename pid13 pid
drop year
save "C:\Replication\personality.dta", replace



* 4) type of marriage: data set id5d

// again, only those with a change in marital status or in the number of children are interviewed in 2013; for others, information needs to be 
// retrieved from earlier waves


*** 2013 data 
use "C:\Data\LiK2013\id5d.dta", clear


* number of marriages

// we are only interested in those who ever married 
keep if i519 != .
// 476 observations in total
tab i519
// 460 married once, 15 married twice, 1 married more than twice - this person reports to still be married with her second spouse, we therefore regard 
// the answer to i519 to be incorrect and this observation to have married twice (not more than twice) 

// we are only interested in the current marriage, i.e. the first marriage for those married for the first time, and the second marriage for those 
// married for the second time
gen no_married = 1 if i519 == 1 
replace no_married = 2 if i519 == 2 | i519 == 3
replace no_married = 1 if hhid == 3390 & pid == 4
// this person reported to be married twice but did not report anything on the second marriage; we assume there was no second marriage
// (mistake was discovered below)


* variable for age at marriage for wife and husband
gen age_marr_wife = i520_1 if no_married == 1
replace age_marr_wife = i520_2 if no_married == 2
replace age_marr_wife = . if i520_1 == 99 | i520_2 == 99
lab var age_marr_wife "wife's age at current marriage"

gen age_marr_husb = i521_1 if no_married == 1
replace age_marr_husb = i521_2 if no_married == 2
replace age_marr_husb = . if i521_1 == 99 | i521_2 == 99
lab var age_marr_husb "husband's age at current marriage"
// I get one couple with missing values because obviously the info in i519 is incorrect: they married only once 
// I correct this above (hhid=3390,pid=4)


* type of marriage
gen type_marr = i522_1 if no_married == 1
replace type_marr = i522_2 if no_married == 2
lab var type_marr "type of current marriage"
lab def type_marr 1 "love marriage" 2 "arranged marriage" 3 "bride capture"
lab val type_marr type_marr

keep hhid pid no_married age_marr_wife age_marr_husb type_marr
save "C:\Replication\marriage13.dta", replace



*** 2012 data
use "C:\Data\LiK2012\id5d.dta", clear
// also here, only those with a change in marital status or in the number of children are interviewed

* number of marriages
// we are only interested in those who ever married 
keep if i519 != .
// 313 observations in total
tab i519
// 300 married once, 13 married twice

// we are only interested in the current marriage, i.e. the first marriage for those married for the first time, and the second marriage for those 
// married for the second time
gen no_married = 1 if i519 == 1 
replace no_married = 2 if i519 == 2 | i519 == 3


* variable for age at marriage for wife and husband
gen age_marr_wife = i520_1 if no_married == 1
replace age_marr_wife = i520_2 if no_married == 2
lab var age_marr_wife "wife's age at current marriage"

gen age_marr_husb = i521_1 if no_married == 1
replace age_marr_husb = i521_2 if no_married == 2
lab var age_marr_husb "husband's age at current marriage"


* type of marriage
gen type_marr = i522_1 if no_married == 1
replace type_marr = i522_2 if no_married == 2
lab var type_marr "type of current marriage"
lab def type_marr 1 "love marriage" 2 "arranged marriage" 3 "bride capture"
lab val type_marr type_marr

keep hhid pid no_married age_marr_wife age_marr_husb type_marr
save "C:\Replication\marriage12.dta", replace



*** 2011 data 
// I need to go back to the 2011 data because only those women with a change in marital status or number of children provide information 
// in the later waves
use "C:\Data\LiK2011\id5d.dta", clear

* number of marriages
// only those with a change in marital status or number of children are interviewed
// we are only interested in those who ever married 
keep if i519 != .
// 3,591 observations in total
tab i519
// 3,415 married once, 171 married twice, 5 married more than twice
// we exclude these 5 observations (4 of them report that they are no longer married with their second husband; so I assume the info in i519 is correct)
drop if i519 == 3


// we are only interested in the current marriage, i.e. the first marriage for those married for the first time, and the second marriage for those 
// married for the second time
gen no_married = 1 if i519 == 1 
replace no_married = 2 if i519 == 2 | i519 == 3
replace no_married = 1 if hhid == 6276 & pid == 4
// this person made a mistake in reporting, discovered below but already corrected here


* variable for age at marriage for wife and husband
gen age_marr_wife = i520_1 if no_married == 1
replace age_marr_wife = i520_2 if no_married == 2
lab var age_marr_wife "wife's age at current marriage"
// 1 value = 90, 18 = 99 
// these are certainly not true values, but are missing values
replace age_marr_wife = . if age_marr_wife == 99 
// the person with not applicable appears to be married the first time
// I correct this above

gen age_marr_husb = i521_1 if no_married == 1
replace age_marr_husb = i521_2 if no_married == 2
lab var age_marr_husb "husband's age at current marriage"
// 1 value = 90, 23 = 99 
// these are certainly not true values, but missing values
replace age_marr_husb = . if age_marr_husb == 99 


* type of marriage
gen type_marr = i522_1 if no_married == 1
replace type_marr = i522_2 if no_married == 2
lab var type_marr "type of current marriage"
lab def type_marr 1 "love marriage" 2 "arranged marriage" 3 "bride capture"
lab val type_marr type_marr

keep hhid pid no_married age_marr_wife age_marr_husb type_marr
save "C:\Replication\marriage11.dta", replace


**** combine data from different years
use "C:\Replication\merge11_13.dta", clear
// this dataset identifies individuals over time
* one duplicate
drop if hhid11 == 6066 & pid11 == 3 & hhid13 == .
rename hhid11 hhid 
rename pid11 pid
sort hhid pid 
merge 1:1 hhid pid using "C:\Replication\marriage11.dta"
// 3,434
keep if _m == 3
drop _m
rename hhid hhid11
rename pid pid11
rename hhid13 hhid
rename pid13 pid
gen year = 2011
save "C:\Replication\marriage11_help.dta", replace 

use "C:\Replication\merge11_13.dta", clear
// this dataset identifies individuals over time
* one duplicate
drop if hhid11 == 6066 & pid11 == 3 & hhid13 == .
rename hhid12 hhid 
rename pid12 pid
drop if pid == .
sort hhid pid 
merge 1:1 hhid pid using "C:\Replication\marriage12.dta"
// 205 merged
keep if _m == 3
drop _m
rename hhid hhid12
rename pid pid12
rename hhid13 hhid
rename pid13 pid
gen year = 2012
save "C:\Replication\marriage12_help.dta", replace 


use "C:\Replication\marriage13.dta", clear
gen year = 2013
append using "C:\Replication\marriage12_help.dta"
append using "C:\Replication\marriage11_help.dta"
sort hhid pid year
drop if hhid == . | pid == .
duplicates list hhid pid 
// 306 duplicates
// many of them provide identical information in the different years, few provide different type of marriage, and very few married a second time
// because of the latter case, I use the information from the latest year because people may have married a different partner
by hhid pid: gen count = _n
by hhid pid: gen count_help = _N

drop if count_help == 3 & (count == 1 | count == 2)
// 32 dropped
drop if count_help == 2 & count == 1
// 290 dropped
drop count count_help
drop year hhid11 pid11 hhid12 pid12
sort hhid pid
save "C:\Replication\marriage.dta", replace

