********************************************************************************
******** Build the dataset from 2013 for the assortative mating results ********
********************************************************************************

clear all
set more off
cap log close


* 1) Define the couples - IDs for spouses explicitly mentioned in household roster

use "C:\Data\LiK2013\hh1a.dta", clear


**** Following is a set of corrections which were only discovered below but already made at the beginning of the file after having been discovered. 

* 1) HHID 4008, pid 2
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 4008 & pid == 1

* 2) HHID 4074, pid 2 
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 4074 & pid == 1

* 3) HHID 5179, pid 2 
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 5179 & pid == 1

* 4) HHID 5194, pid 2 
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 5194 & pid == 1

* 5) HHID 6091, pid 7 
* this person is likely married with pid 5 (as reported) but pid 5 is reported to be single; we don't think single is true
replace h108a = 7 if hhid == 6091 & pid == 5

* 6) HHID 6125, pid 2
* this person reports to be married with pid 6 but there is no pid 6 in this HH
replace h108a = . if hhid == 6125 & pid == 2

* 7) HHID 6273, pid 2
* this person is likely married with pid 3 (as reported) but pid 3 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 6273 & pid == 3

* 8) HHID 6299, pid 5
* this person is likely married with pid 9 (as reported) but pid 9 is reported to be widowed; we don't think widowed is true
replace h108a = 5 if hhid == 6299 & pid == 9

* 9) HHID 6342, pid 3
* this person reports to be married with pid 6 but there is no pid 6 in this HH
replace h108a = . if hhid == 6342 & pid == 3

* 10) HHID 6392, pid 2
* this person reports to be married with pid 4 but there is no pid 4 in this HH
replace h108a = . if hhid == 6392 & pid == 2

* 11) HHID 6462, pid 5
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be widowed; we don't think widowed is true
replace h108a = 5 if hhid == 6462 & pid == 1

* 12) HHID 7103, pid 2
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 7103 & pid == 1

* 13) HHID 7104, pid 2
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 7104 & pid == 1

* 13) HHID 8001, pid 2
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 8001 & pid == 1

* 14) HHID 8065, pid 2
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 8065 & pid == 1

* 15) HHID 8335, pid 5
* this person reports to be married with pid 6 but there is no pid 6 in this HH
replace h108a = . if hhid == 8335 & pid == 5

* 16) HHID 8435, pid 2
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 8435 & pid == 1

* 17) HHID 11115, pid 3
* this person reports to be married with pid 6 but there is no pid 6 in this HH
replace h108a = . if hhid == 11115 & pid == 3

* 18) HHID 11390, pid 2
* this person is likely married with pid 1 (as reported) but pid 1 is reported to be divorced; we don't think divorce is true
replace h108a = 2 if hhid == 11390 & pid == 1

* 19) HHID 11422, pid 3
* this person is likely married with pid 6 (as reported) but pid 6 is reported to be single; we don't think single is true
replace h108a = 3 if hhid == 11422 & pid == 6

* 20) HHID 21148, pid 1
* this person reports to be married with pid 7 but there is no pid 7 in this HH
replace h108a = . if hhid == 21148 & pid == 1




**** corrections for spouses that obtained a wrong ID during data entry
replace h108a = 6 if hhid == 6139 & pid == 3
replace h108a = 10 if hhid == 6188 & pid == 6
replace h108a = 10 if hhid == 21144 & pid == 6



drop if h108a == .
rename h108a pid_spouse
gen wife = (h102 == 2)
gen husband = (h102 == 1)

// spouse cannot have the same ID as oneself
count if pid == pid_spouse

// the same individual can only be named once as a spouse within each household
sort hhid pid_spouse 
by hhid pid_spouse: egen count = count(pid_spouse)
tab count, m
* 24 observations are counted twice
* 3 observations are counted three times
list hhid pid_spouse if count == 2 | count == 3
* check these cases by hand in the original household roster

* 1) HHID 3216, pid_spouse 0 
* both people are children of the head, cannot recognize a spouse in the roster
replace pid_spouse = . if hhid == 3216 & pid_spouse == 0

* 2) HHID 3237, pid_spouse 6
* both are daughters of the head, cannot recognize a spouse in the roster
replace pid_spouse = . if hhid == 3237 & pid_spouse == 6

* 3) HHID 4072, pid_spouse 0
* both are daughters of the head, cannot recognize a spouse in the roster
replace pid_spouse = . if hhid == 4072 & pid_spouse == 0

* 4) HHID 6092, pid_spouse 6
* both are children of the head, cannot recognize a spouse in the roster
replace pid_spouse = . if hhid == 6092 & pid_spouse == 6

* 5) HHID 6351, pid_spouse 3 and 4
* there are obviously two, clearly identifiable couples in the HH that got the same pid_spouse
replace pid_spouse = 9 if hhid == 6351 & pid == 8
replace pid_spouse = 8 if hhid == 6351 & pid == 9

* 6) HHID 6436, pid_spouse 2
* both are sons of the head, cannot be married to their mother
replace pid_spouse = . if hhid == 6436 & pid == 4
replace pid_spouse = . if hhid == 6436 & pid == 5

* 7) HHID 6463, pid_spouse 3
* this appears to be a polygamous family with pid = 3 married to two wives: pid = 6 and pid = 10

* 8) HHID 8198, pid_spouse 6
* both are children of the head, cannot recognize a spouse in the roster
replace pid_spouse = . if hhid == 8198 & pid_spouse == 6

* 9) HHID 11013, pid_spouse 0
* both are divorced individuals 
replace pid_spouse = . if hhid == 11013 & pid_spouse == 0

* 10) HHID 11015, pid_spouse 0
* both are widowed individuals 
replace pid_spouse = . if hhid == 11015 & pid_spouse == 0

* 11) HHID 11234, pid_spouse 6
* both are children of the head, cannot recognize a spouse in the roster
replace pid_spouse = . if hhid == 11234 & pid_spouse == 6

* 12) HHID 11249, pid_spouse 0
* both are children of the head, cannot recognize a spouse in the roster
replace pid_spouse = . if hhid == 11249 & pid_spouse == 0

* check that changes leave no more suspicuous cases
drop if pid_spouse == .
drop count
sort hhid pid_spouse 
by hhid pid_spouse: egen count = count(pid_spouse)
tab count, m
list hhid pid_spouse if count == 2 | count == 3
// the only remaining one is the polygamous family
drop count

// check the pid of the spouse
tab pid_spouse
// 18 observations that have pid_spouse == 0
list hhid pid if pid_spouse == 0
// again, go through these in the original household roster by hand
// none of the cases seems to have a husband, at least not one who is listed as a household member (many - both the HH member and the missing spouses - may be migrants)
drop if pid_spouse == 0


// the dataset should now consist of couples only
// per household, there should be even numbers of observations
sort hhid pid
by hhid: gen count = _N 
tab count, m
// there 12 observations with 1 person, 24 observations with 3 people within the household and 10 with 5 
list hhid pid if count == 1 | count == 3 | count == 5
// corrections are made above (at the very beginning of the file)
// the only remaining problem is the polygamous household
// I drop the one spouse in this household that was not mentioned by the husband (Caution: not the perfect remedy!)
drop if hhid == 6463 & pid == 10
drop count

save "C:\Replication\couples.dta", replace




* Some of the resulting couples might not have been completely interviewed; one of the spouses may have refused or been away at the time of the survey
* Two ways to get more info: 
* 1) Check how many couples remain when we require full information from modules from the individual questionnaire
* 2) In the control page of the individual questionnaire, there is information about whether someone else was present during the interview
* Even if we do not know whether this was the spouse, we can make use of this information: If it is recorded for both spouses that someone else was 
* present, then we may assume (though not know for sure!) that the spouse was there

* Save the information on the presence of someone during the interview to be merged later
use "C:\Data\LiK2013\id0.dta", clear
keep hhid pid presenci
rename presenci present
* currently, the answer code 2 is used for "no"; change this to 0 to make it a dummy variable
replace present = 0 if present == 2
save "C:\Replication\presence.dta", replace


* Merge the first individual module
use "C:\Replication\couples.dta", replace
sort hhid pid
merge 1:1 hhid pid using "C:\Data\LiK2013\id1.dta"
keep if _m == 3 | _m == 1
rename _merge merger
// 5,256 are matched
// 368 have not been interviewed, many of these are reported in h109 to have been away from the household in the last week
merge 1:1 hhid pid using "C:\Replication\presence.dta"
keep if _m == 3 | _m == 1
drop _m
keep hhid pid pid_spouse wife husband merger present

gen pid_husband = pid if husband == 1
gen pid_wife = pid if wife == 1

gen present_wife = present if wife == 1
gen present_husband = present if husband == 1

save "C:\Replication\couples_help.dta", replace

drop if pid_husband == .
keep hhid pid_husband pid_spouse merger present_husband
rename merger husband_merge
rename pid_spouse pid_wife
sort hhid pid_wife
save "C:\Replication\husband_help.dta", replace

use "C:\Replication\couples_help.dta", clear
drop if pid_wife == .
keep hhid pid_wife merger present_wife present 
rename merger wife_merge
save "C:\Replication\wife_help.dta", replace

use "C:\Replication\husband_help.dta", clear
merge 1:1 hhid pid_wife using "C:\Replication\wife_help.dta"
// at first try, 3 couples do not match; but can easily be corrected as the husband_id was only wrongly entered during data entry
// I make these corrections above
// now all 2812 couples merged
drop _m



* merge geographical information (need community and district)
rename hhid hhid13
merge m:1 hhid13 using "C:\Data\LiK2013\cc_hh.dta", keepusing(oblast soato psu)
keep if _m == 3
drop _m
rename hhid13 hhid


* generate district variable from the community code
gen help = int(soato/1000000)
format help %12.0g
// identification of rayon (i.e. district) must rely on this variable 
sort help
egen rayon_id = group(help)
codebook rayon_id 
// 47 different rayons



* we give the couples IDs
sort oblast hhid 
gen couple_id = _n

lab var pid_husband "ID of the husband"
lab var pid_wife "ID of the wife"

save "C:\Replication\couples_final.dta", replace


* make this a husband and a wife dataset
drop pid_husband
rename pid_wife pid
save "C:\Replication\wife_final.dta", replace


use "C:\Replication\couples_final.dta", clear
drop pid_wife
rename pid_husband pid
save "C:\Replication\husband_final.dta", replace





********************************************************************************
*** merge with information from the modules

use "C:\Replication\wife_final.dta", clear
sort hhid pid 
merge 1:1 hhid pid using "C:\Replication\marriage.dta"
// 2,520 merged
drop if _m == 2
drop _m

sort hhid pid
merge 1:1 hhid pid using "C:\Replication\roster.dta"
// 2,812 merged
keep if _m == 3
drop _m

merge 1:1 hhid pid using "C:\Replication\education.dta"
// 2,685 merged
drop if _m == 2
drop _m

merge 1:1 hhid pid using "C:\Replication\personality.dta"
// 2,695 merged
drop if _m == 2
drop _m




* drop individual IDs; only need the couple ID from now on
drop hhid12 pid12 /*hhid pid*/
* rename the variables to mark them as the wife's information
rename age w_age
rename ethnicity w_ethnicity
rename education w_education

forvalues i = 1(1)21 {
	rename pers`i' w_pers`i' 	
	}

save "C:\Replication\wifes.dta", replace



use "C:\Replication\husband_final.dta", clear
sort hhid pid
merge 1:1 hhid pid using "C:\Replication\roster.dta"
// 2,812 merged
keep if _m == 3
drop _m

merge 1:1 hhid pid using "C:\Replication\education.dta"
// 2,640 merged
drop if _m == 2
drop _m

merge 1:1 hhid pid using "C:\Replication\personality.dta"
// 2,651 merged
drop if _m == 2
drop _m



* drop individual IDs; only need the couple ID from now on
drop hhid12 pid12 /*hhid pid*/
* rename the variables to mark them as the husband's information
rename age h_age
rename ethnicity h_ethnicity
rename education h_education

forvalues i = 1(1)21 {
	rename pers`i' h_pers`i' 	
	}

	
save "C:\Replication\husbands.dta", replace

merge 1:1 couple_id using "C:\Replication\wifes.dta"
drop _m




* calculate duration of marriage
gen dur_marr = w_age - age_marr_wife
gen dur_marr_h = h_age - age_marr_husb

tab dur_marr
tab dur_marr_h
// duration of marriage according to husbands' age has quite a number of negative values
// it seems more reliable to work with duration calculated on the basis of wife's age; this also makes sense because the women reported their age at 
// marriage themselves but report it for their husbands (more scope for mistakes)
// there is only one value = -1


* calculate schooling years and difference in schooling between husband and wife
gen h_school = 0 if h_education == 1
replace h_school = 3 if h_education == 2
replace h_school = 8 if h_education == 3
replace h_school = 10 if h_education == 4
replace h_school = 11 if h_education == 5
replace h_school = 13 if h_education == 6
replace h_school = 15 if h_education == 7
replace h_school = 18 if h_education == 8

gen w_school = 0 if w_education == 1
replace w_school = 3 if w_education == 2
replace w_school = 8 if w_education == 3
replace w_school = 10 if w_education == 4
replace w_school = 11 if w_education == 5
replace w_school = 13 if w_education == 6
replace w_school = 15 if w_education == 7
replace w_school = 18 if w_education == 8

save "C:\Replication\final_data.dta", replace



* count the couples for which I have full information
count if w_age != . & h_age != .
// 2,812 

count if w_education != . & h_education != .
// 2,589 

count if w_ethnicity != . & h_ethnicity != .
// 2,812

count if w_pers1 != . & h_pers1 != .
// 2,602





********************************************************************************

* Table 1: Prevalence of marriage type (in %), by couple's ethnic group 

* for Kyrgyz couples
tab type_marr if w_ethnicity == 1 & h_ethnicity == 1

* for Uzbek couples
tab type_marr if w_ethnicity == 2 & h_ethnicity == 2

* for Russian couples
tab type_marr if w_ethnicity == 3 & h_ethnicity == 3

* for Dungan, Uigur, Tajik, Kazakh and other couples
tab type_marr if (w_ethnicity == 4 & h_ethnicity == 4) | (w_ethnicity == 5 & h_ethnicity == 5) | (w_ethnicity == 6 & h_ethnicity == 6) | /*
*/ (w_ethnicity == 7 & h_ethnicity == 7) | (w_ethnicity == 8 & h_ethnicity == 8)

* for inter-ethnic couples
tab type_marr if w_ethnicity != h_ethnicity



* generate a variable for the ethnicity of the couple
gen couple_ethnic = 1 if w_ethnicity == 1 & h_ethnicity == 1
replace couple_ethnic = 2 if w_ethnicity == 2 & h_ethnicity == 2
replace couple_ethnic = 3 if w_ethnicity == 3 & h_ethnicity == 3
replace couple_ethnic = 4 if (w_ethnicity == 4 & h_ethnicity == 4) | (w_ethnicity == 5 & h_ethnicity == 5) | (w_ethnicity == 6 & h_ethnicity == 6) | /*
*/ (w_ethnicity == 7 & h_ethnicity == 7) | (w_ethnicity == 8 & h_ethnicity == 8)
replace couple_ethnic = 5 if w_ethnicity != h_ethnicity
label def ethnic 1 "Kyrgyz couple" 2 "Uzbek couple" 3 "Russian couple" 4 "other couple" 5 "inter-ethnic couple"
label val couple_ethnic ethnic

save "C:\Replication\final_data.dta", replace



