********************************************************************************
*** CALCULATION OF SIMILARITY INDEX FOR OVERALL PERSONALITY (ALL 21 ITEMS) *****
********************************************************************************

clear all 
set more off
cap log close


*** PERSONALITY

use "C:\Replication\final_data.dta", clear

keep couple_id rayon_id hhid psu couple_ethnic h_age w_age h_school w_school h_pers1-h_pers21 type_marr w_pers1- w_pers21 dur_marr 
sort couple_id


* How many couples have missing values in the personality items?
forvalues i = 1(1)21 {
		gen missing_w`i' = (w_pers`i' == .)
		}

forvalues i = 1(1)21 {
		gen missing_h`i' = (h_pers`i' == .)
		}

gen sum_miss_w = missing_w1 + missing_w2 + missing_w3 + missing_w4 + missing_w5 + missing_w6 + missing_w7 + missing_w8 + missing_w9 + missing_w10 + missing_w11 + missing_w12 + missing_w13 + missing_w14 + missing_w15 + missing_w16 + missing_w17 + missing_w18 + missing_w19 + missing_w20 + missing_w21
gen sum_miss_h = missing_h1 + missing_h2 + missing_h3 + missing_h4 + missing_h5 + missing_h6 + missing_h7 + missing_h8 + missing_h9 + missing_h10 + missing_h11 + missing_h12 + missing_h13 + missing_h14 + missing_h15 + missing_h16 + missing_h17 + missing_h18 + missing_h19 + missing_h20 + missing_h21

gen nomiss = (sum_miss_w == 0 & sum_miss_h == 0)
replace nomiss = . if sum_miss_w == . | sum_miss_h == . 
tab nomiss, m
tab nomiss if type_marr != .
tab nomiss if type_marr != ., m

// among our 2,520 couples: for 121 we have no information on all wife's personality items, husband's personality items or both - they did not respond to the module
// 2,399 couples have no missing value at all; we can calculate the profile similarity index only for them


* drop all couples that have any missing values 
forvalues i = 1(1)21 {
	drop if h_pers`i' == . 
	rename h_pers`i' pers`i'_0
	}

forvalues i = 1(1)21 {
	drop if w_pers`i' == . 
	rename w_pers`i' pers`i'_1
	}


reshape long pers1_ pers2_ pers3_ pers4_ pers5_ pers6_ pers7_ pers8_ pers9_ pers10_ pers11_ pers12_ pers13_ pers14_ pers15_ pers16_ pers17_ pers18_ pers19_ pers20_ pers21_, i(couple_id) j(wife)  
 label drop _all
label def wife 1 "wife" 0 "husband"
label val wife wife


*** are the observations always couples?
sort couple_id wife
by couple_id: gen number = _N
tab number 								// yes, all have number = 2; only couples included!


forvalues i = 1(1)21 {
	rename pers`i'_ pers`i'
	}

	
quietly generate double corr = .


* calculate the profile similarity index
tempname M
forvalues row = 1(2)`=_N' {

     matrix dissimilarity `M' = pers1 - pers21 if inlist(_n, `row', `row'+1), correlation
     quietly replace corr = `M'[2, 1] in `row'
}

rename corr corr_pers_profile
tab corr_pers_profile

* calculate Fisher's r-to-z transformation
gen help_pers = (corr_pers_profile == 1 | corr_pers_profile == -1)
tab help_pers if type_marr != .

sum corr_pers_profile if type_marr != .
sum corr_pers_profile if type_marr == 1
sum corr_pers_profile if type_marr == 2
sum corr_pers_profile if type_marr == 3

replace corr_pers_profile = 0.9999 if corr_pers_profile == 1
replace corr_pers_profile = -0.9999 if corr_pers_profile == -1

kdensity corr_pers_profile if type_marr != .
graph save Graph "C:\Replication\corr_pers.gph", replace

* calculate Fisher's r-to-z transformation
gen z_pers = atanh(corr_pers_profile)
kdensity z_pers if type_marr != . 
graph save Graph "C:\Replication\z_pers.gph", replace
// this is Figure 1 in the paper

drop if wife == 1
sort couple_id
count if corr_pers_profile != . 					
// 2,602 but we don't know the marriage type for all of them
count if corr_pers_profile != . & type_marr != .
// 2,399
save "C:\Replication\sim_pers_profile.dta", replace

sum corr_pers_profile if type_marr != .
sum corr_pers_profile if type_marr == 1
sum corr_pers_profile if type_marr == 2
sum corr_pers_profile if type_marr == 3

log using "C:\Replication\regression.log", replace





******************************** Regressions ***********************************
// These are the results in Table 2.

**** regress similarity in personality on the type of marriage 

* 1) all observations
reg z_pers i.type_marr##c.dur_marr, cluster(psu)

* 2) only those not completely identical 
reg z_pers i.type_marr##c.dur_marr if help_pers != 1, cluster(psu)



**** control for demographics (ethnicity of the couple as well as age and education of husband and wife) 

* 1) all observations
reg z_pers i.type_marr##c.dur_marr i.couple_ethnic c.w_age##c.h_age c.w_school##c.h_school, cluster(psu)

* 2) only those not completely identical 
reg z_pers i.type_marr##c.dur_marr i.couple_ethnic c.w_age##c.h_age c.w_school##c.h_school if help_pers != 1, cluster(psu)



**** add district indicators (rayon_id)

* 1) all observations
reg z_pers i.type_marr##c.dur_marr i.couple_ethnic c.w_age##c.h_age c.w_school##c.h_school i.rayon_id, cluster(psu)

* 2) only those not completely identical 
reg z_pers i.type_marr##c.dur_marr i.couple_ethnic c.w_age##c.h_age c.w_school##c.h_school i.rayon_id if help_pers != 1, cluster(psu)



**** restrict to Kyrgyz only

* 1) all observations
reg z_pers i.type_marr##c.dur_marr c.w_age##c.h_age c.w_school##c.h_school i.rayon_id if couple_ethnic == 1, cluster(psu)

* 2) only those not completely identical 
reg z_pers i.type_marr##c.dur_marr c.w_age##c.h_age c.w_school##c.h_school i.rayon_id if couple_ethnic == 1 & help_pers ! = 1, cluster(psu)


log close
exit







