****************************************************************************************************************
*** CALCULATION OF SIMILARITY INDEXES FOR THE BIG FIVE PERSOANLITY TRAITS AND RUN REGRESSIONS FOR THEM *********
****************************************************************************************************************

clear all 
set more off
cap log close


*** PERSONALITY

*** Profile similarity index (varies from -1 to 1)
// can only be calculated for those couples without any missing values



use "C:\Replication\final_data.dta", clear

* I drop all couples that have any missing values
forvalues i = 1(1)21 {
	drop if h_pers`i' == . 
	}

forvalues i = 1(1)21 {
	drop if w_pers`i' == . 
	}
	
	
* Factor 1: Conscientiousness
* these are personality statements 3, 8, 13, 18 (as implied by SOEP data)
keep couple_id h_pers3 h_pers8 h_pers13 h_pers18 w_pers3 w_pers8 w_pers13 w_pers18
sort couple_id


gen h_mean = (h_pers3 + h_pers8 + h_pers13 + h_pers18)/4
gen w_mean = (w_pers3 + w_pers8 + w_pers13 + w_pers18)/4

gen h3minusmean = h_pers3 - h_mean
gen h8minusmean = h_pers8 - h_mean
gen h13minusmean = h_pers13 - h_mean
gen h18minusmean = h_pers18 - h_mean

gen w3minusmean = w_pers3 - w_mean
gen w8minusmean = w_pers8 - w_mean
gen w13minusmean = w_pers13 - w_mean
gen w18minusmean = w_pers18 - w_mean

gen numerator = h3minusmean*w3minusmean + h8minusmean*w8minusmean + h13minusmean*w13minusmean + h18minusmean*w18minusmean

gen denominator = sqrt((h3minusmean*h3minusmean + h8minusmean*h8minusmean + h13minusmean*h13minusmean + h18minusmean*h18minusmean) * /*
               */ (w3minusmean*w3minusmean + w8minusmean*w8minusmean + w13minusmean*w13minusmean + w18minusmean*w18minusmean)) 
			  
gen profile_cons = numerator/denominator			 
keep couple_id profile_cons

* calculate Fisher's r-to-z transformation
replace profile_cons = 0.9999 if profile_cons == 1
replace profile_cons = -0.9999 if profile_cons == -1
gen z_cons = atanh(profile_cons)
kdensity z_cons  

sort couple_id
save "C:\Replication\profile_cons.dta", replace



**** 2)
use "C:\Replication\final_data.dta", clear

* I drop all couples that have any missing values 
forvalues i = 1(1)21 {
	drop if h_pers`i' == . 
	}

forvalues i = 1(1)21 {
	drop if w_pers`i' == . 
	}
	

	
* Factor 2: Openness
* these are personality statements 5, 10, 15, 20, 21
keep couple_id h_pers5 h_pers10 h_pers15 h_pers20 h_pers21 w_pers5 w_pers10 w_pers15 w_pers20 w_pers21
sort couple_id

gen h_mean = (h_pers5 + h_pers10 + h_pers15 + h_pers20 + h_pers21)/5
gen w_mean = (w_pers5 + w_pers10 + w_pers15 + w_pers20 + w_pers21)/5

gen h5minusmean = h_pers5 - h_mean
gen h10minusmean = h_pers10 - h_mean
gen h15minusmean = h_pers15 - h_mean
gen h20minusmean = h_pers20 - h_mean
gen h21minusmean = h_pers21 - h_mean

gen w5minusmean = w_pers5 - w_mean
gen w10minusmean = w_pers10 - w_mean
gen w15minusmean = w_pers15 - w_mean
gen w20minusmean = w_pers20 - w_mean
gen w21minusmean = w_pers21 - w_mean

gen numerator = h5minusmean*w5minusmean + h10minusmean*w10minusmean + h15minusmean*w15minusmean + h20minusmean*w20minusmean + h21minusmean*w21minusmean

gen denominator = sqrt((h5minusmean*h5minusmean + h10minusmean*h10minusmean + h15minusmean*h15minusmean + h20minusmean*h20minusmean + h21minusmean*h21minusmean) * /*
               */ (w5minusmean*w5minusmean + w10minusmean*w10minusmean + w15minusmean*w15minusmean + w20minusmean*w20minusmean + w21minusmean*w21minusmean)) 
			  
gen profile_open = numerator/denominator			 
keep couple_id profile_open

* calculate Fisher's r-to-z transformation
replace profile_open = 0.9999 if profile_open == 1
replace profile_open = -0.9999 if profile_open == -1
gen z_open = atanh(profile_open)
kdensity z_open

sort couple_id
save "C:\Replication\profile_open.dta", replace



**** 3)
use "C:\Replication\final_data.dta", clear

* I drop all couples that have any missing values 
forvalues i = 1(1)21 {
	drop if h_pers`i' == . 
	}

forvalues i = 1(1)21 {
	drop if w_pers`i' == . 
	}
	

	
* Factor 3: Agreeableness
* these are personality statements 2, 7, 12, 17
keep couple_id h_pers2 h_pers7 h_pers12 h_pers17 w_pers2 w_pers7 w_pers12 w_pers17
sort couple_id

gen h_mean = (h_pers2 + h_pers7 + h_pers12 + h_pers17)/4
gen w_mean = (w_pers2 + w_pers7 + w_pers12 + w_pers17)/4

gen h2minusmean = h_pers2 - h_mean
gen h7minusmean = h_pers7 - h_mean
gen h12minusmean = h_pers12 - h_mean
gen h17minusmean = h_pers17 - h_mean

gen w2minusmean = w_pers2 - w_mean
gen w7minusmean = w_pers7 - w_mean
gen w12minusmean = w_pers12 - w_mean
gen w17minusmean = w_pers17 - w_mean


gen numerator = h2minusmean*w2minusmean + h7minusmean*w7minusmean + h12minusmean*w12minusmean + h17minusmean*w17minusmean

gen denominator = sqrt((h2minusmean*h2minusmean + h7minusmean*h7minusmean + h12minusmean*h12minusmean + h17minusmean*h17minusmean) * /*
               */ (w2minusmean*w2minusmean + w7minusmean*w7minusmean + w12minusmean*w12minusmean + w17minusmean*w17minusmean)) 
			  
gen profile_agree = numerator/denominator			 
keep couple_id profile_agree

* calculate Fisher's r-to-z transformation
replace profile_agree = 0.9999 if profile_agree == 1
replace profile_agree = -0.9999 if profile_agree == -1
gen z_agree = atanh(profile_agree)
kdensity z_agree

sort couple_id
save "C:\Replication\profile_agree.dta", replace





*** 4)
use "C:\Replication\final_data.dta", clear

* I drop all couples that have any missing values 
forvalues i = 1(1)21 {
	drop if h_pers`i' == . 
	}

forvalues i = 1(1)21 {
	drop if w_pers`i' == . 
	}
	

* Factor 4: Extraversion
* these are personality statements 1, 6, 11, 16
keep couple_id h_pers1 h_pers6 h_pers11 h_pers16 w_pers1 w_pers6 w_pers11 w_pers16
sort couple_id

gen h_mean = (h_pers1 + h_pers6 + h_pers11 + h_pers16)/4
gen w_mean = (w_pers1 + w_pers6 + w_pers11 + w_pers16)/4

gen h1minusmean = h_pers1 - h_mean
gen h6minusmean = h_pers6 - h_mean
gen h11minusmean = h_pers11 - h_mean
gen h16minusmean = h_pers16 - h_mean

gen w1minusmean = w_pers1 - w_mean
gen w6minusmean = w_pers6 - w_mean
gen w11minusmean = w_pers11 - w_mean
gen w16minusmean = w_pers16 - w_mean


gen numerator = h1minusmean*w1minusmean + h6minusmean*w6minusmean + h11minusmean*w11minusmean + h16minusmean*w16minusmean

gen denominator = sqrt((h1minusmean*h1minusmean + h6minusmean*h6minusmean + h11minusmean*h11minusmean + h16minusmean*h16minusmean) * /*
               */ (w1minusmean*w1minusmean + w6minusmean*w6minusmean + w11minusmean*w11minusmean + w16minusmean*w16minusmean)) 
			  
gen profile_extra = numerator/denominator			 
keep couple_id profile_extra

* calculate Fisher's r-to-z transformation
replace profile_extra = 0.9999 if profile_extra == 1
replace profile_extra = -0.9999 if profile_extra == -1
gen z_extra = atanh(profile_extra)
kdensity z_extra

sort couple_id
save "C:\Replication\profile_extra.dta", replace




**** 5)
use "C:\Replication\final_data.dta", clear

* I drop all couples that have any missing values 
forvalues i = 1(1)21 {
	drop if h_pers`i' == . 
	}

forvalues i = 1(1)21 {
	drop if w_pers`i' == . 
	}
	

* Factor 5: Neuroticism
* these are personality statements 4, 9, 14, 19
keep couple_id h_pers4 h_pers9 h_pers14 h_pers19 w_pers4 w_pers9 w_pers14 w_pers19
sort couple_id

gen h_mean = (h_pers4 + h_pers9 + h_pers14 + h_pers19)/4
gen w_mean = (w_pers4 + w_pers9 + w_pers14 + w_pers19)/4

gen h4minusmean = h_pers4 - h_mean
gen h9minusmean = h_pers9 - h_mean
gen h14minusmean = h_pers14 - h_mean
gen h19minusmean = h_pers19 - h_mean

gen w4minusmean = w_pers4 - w_mean
gen w9minusmean = w_pers9 - w_mean
gen w14minusmean = w_pers14 - w_mean
gen w19minusmean = w_pers19 - w_mean


gen numerator = h4minusmean*w4minusmean + h9minusmean*w9minusmean + h14minusmean*w14minusmean + h19minusmean*w19minusmean

gen denominator = sqrt((h4minusmean*h4minusmean + h9minusmean*h9minusmean + h14minusmean*h14minusmean + h19minusmean*h19minusmean) * /*
               */ (w4minusmean*w4minusmean + w9minusmean*w9minusmean + w14minusmean*w14minusmean + w19minusmean*w19minusmean)) 
			  
gen profile_neuro = numerator/denominator			 
keep couple_id profile_neuro

* calculate Fisher's r-to-z transformation
replace profile_neuro = 0.9999 if profile_neuro == 1
replace profile_neuro = -0.9999 if profile_neuro == -1
gen z_neuro = atanh(profile_neuro)
kdensity z_neuro

sort couple_id
save "C:\Replication\profile_neuro.dta", replace




merge 1:1 couple_id using "C:\Replication\profile_open.dta"
drop _m
merge 1:1 couple_id using "C:\Replication\profile_cons.dta"
drop _m
merge 1:1 couple_id using "C:\Replication\profile_agree.dta"
drop _m
merge 1:1 couple_id using "C:\Replication\profile_extra.dta"
drop _m

save "C:\Replication\profile_byhand.dta", replace


use "C:\Replication\final_data.dta", clear
keep couple_id soato rayon_id hhid psu couple_ethnic h_age w_age h_school w_school type_marr dur_marr present
sort couple_id

merge 1:1 couple_id using "C:\Replication\profile_byhand.dta"


******************************** Estimations ***********************************

**** regress similarity in personality on the type of marriage 

* 1) Openness
reg z_open i.type_marr##c.dur_marr i.couple_ethnic c.w_age##c.h_age c.w_school##c.h_school i.rayon_id, cluster(psu)

* 2) Conscientiousness
reg z_cons i.type_marr##c.dur_marr i.couple_ethnic c.w_age##c.h_age c.w_school##c.h_school i.rayon_id, cluster(psu)

* 3) Agreeableness
reg z_agree i.type_marr##c.dur_marr i.couple_ethnic c.w_age##c.h_age c.w_school##c.h_school i.rayon_id, cluster(psu)

* 4) Extraversion
reg z_extra i.type_marr##c.dur_marr i.couple_ethnic c.w_age##c.h_age c.w_school##c.h_school i.rayon_id, cluster(psu)

* 5) Neuroticism
reg z_neuro i.type_marr##c.dur_marr i.couple_ethnic c.w_age##c.h_age c.w_school##c.h_school i.rayon_id, cluster(psu)


